@@ -1,7 +1,16 @@
 from prelude_parser._prelude_parser import (
+    Category,
+    Comment,
+    Entry,
+    Field,
+    Form,
+    Reason,
     SiteNative,
+    State,
     SubjectNative,
     UserNative,
+    Value,
+    __version__,
     parse_site_native_file,
     parse_site_native_string,
     parse_subject_native_file,
@@ -9,15 +18,24 @@ from prelude_parser._prelude_parser import (
     parse_user_native_file,
     parse_user_native_string,
 )
-from prelude_parser._version import VERSION
 from prelude_parser.parser import parse_to_classes, parse_to_dict
 
-__version__ = VERSION
-
 __all__ = [
+    "Category",
+    "Comment",
+    "Entry",
+    "Field",
+    "Form",
+    "Reason",
     "SiteNative",
+    "SiteNative",
+    "State",
+    "SubjectNative",
     "SubjectNative",
     "UserNative",
+    "UserNative",
+    "Value",
+    "__version__",
     "parse_site_native_file",
     "parse_site_native_string",
     "parse_subject_native_file",
